afc.mp: 2AFC For Ordinal Polychotomous Observations And Probabilistic...

View source: R/afc.mp.R

afc.mpR Documentation

2AFC For Ordinal Polychotomous Observations And Probabilistic Forecasts

Description

Routine to calculate the Generalized Discrimination Score (aka Two-Alternatives Forced Choice Score 2AFC) for the situation of polychotomous observations (ordinal) and discrete probabilistic forecasts

Usage

afc.mp(obsv, fcst, m = 3, na.rm = FALSE)

Arguments

obsv

vector with polychotomous observations (values in {1,..,m})

fcst

two-dimensional array with forecast probabilities for the m categories; dim(fcst)[1] = length(obsv); dim(fcst)[2] = m

m

number of observation categories (default = 3)

na.rm

logical; if TRUE pairs where obsv or fcst is NA are removed before scoring. Default FALSE returns NA if any input contains NA.

Details

This routine applies Eq.16 of Mason and Weigel (2009) to calculate the 2AFC.

Value

p.afc

Value of Generalized Discrimination (2AFC) Score

Author(s)

Andreas Weigel, Federal Office of Meteorology and Climatology, MeteoSwiss, Zurich, Switzerland

References

S.J. Mason and A.P. Weigel, 2009. A generic verification framework for administrative purposes. Mon. Wea. Rev., 137, 331-349

See Also

afc

Examples

  data(cnrm.nino34.mp)
  obsv = cnrm.nino34.mp$obsv
  fcst = cnrm.nino34.mp$fcst
  afc.mp(obsv,fcst,4)

afc documentation built on Sept. 11, 2026, 9:08 a.m.