| cnrm.nino34.mp | R Documentation |
Polychotomous observations with four categories (obsv) and discrete probabilistic forecasts (fcst) of the Nino-3.4 index for January 1961-2000. The forecast data stem from model runs initialized using data for the preceding August 1960-1999. Definition of the four observation "categories": (1) obsv < 26 C; (2) obsv in [26 C,27 C[; (3) obsv in [27 C,28 C[; (4) obsv >= 28 C. The probabilistic forecasts have been estimated by taking the fraction of ensemble members falling into each of the four categories.
A data frame with 40 rows and 3 columns:
integer, year of observation (1961-2000)
integer, polychotomous observations (categories 1-4; (1) < 26 C; (2) 26-27 C; (3) 27-28 C; (4) >= 28 C)
numeric matrix [40 x 4], probabilistic forecasts (fraction of ensemble members in each of the 4 categories)
The forecast data are from the coupled ocean-atmosphere model of the Centre National de Recherches Meteorologiques (CNRM) of Meteo France and were generated as part of the "Development of a European Multimodel Ensemble System for Seasonal to Interannual Prediction (DEMETER)" project (Palmer et al. 2004). Note that also the examples presented in the 2AFC paper by Mason and Weigel (2009) are based on these data.
Palmer, T.N. and Coauthors, 2004: Development of a European
ensemble system for seasonal to inter-annual prediction (DEMETER). Bull.
Amer. Meteor. Soc., 85, 853-872.
Mason, S.J. and A.P. Weigel, 2009: A
generic forecast verification framework for administrative purposes. Mon.
Wea. Rev., 137, 331-349
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.